==> applet-annotation-3.1.4-sources.jar: cn/sinozg/applet/common/serializer/UtcOutSerializer.java <==
/*
 * Copyright (C) 2020-2024, Xie YuBin
 * The GNU Free Documentation License covers this file. The original version
 * of this license can be found at http://www.gnu.org/licenses/gfdl.html.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Free Documentation License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Free Documentation License for more details.
 *
 * You should have received a copy of the GNU Free Documentation License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package cn.sinozg.applet.common.serializer;

import cn.sinozg.applet.common.annotation.UtcOut;
import cn.sinozg.applet.common.utils.DateUtil;
import cn.sinozg.applet.common.utils.PojoUtil;
import cn.sinozg.applet.common.utils.TirsciUtil;
import cn.sinozg.applet.common.utils.UserUtil;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.BeanProperty;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.JsonSerializer;
import com.fasterxml.jackson.databind.SerializerProvider;
import com.fasterxml.jackson.databind.ser.ContextualSerializer;
import java.io.IOException;
import java.time.LocalDateTime;
import org.apache.commons.lang3.StringUtils;

/**
 * 时间根据utc 转为 显示时间
 * @author xieyubin
 * @Description
 * @Copyright Copyright (c) 2024
 * @since 2024-11-24 17:51
 */
public class UtcOutSerializer extends JsonSerializer<LocalDateTime> implements ContextualSerializer {

    private String pattern;

    @Override
    public void serialize(LocalDateTime ldt, JsonGenerator gen, SerializerProvider serializerProvider) throws IOException {
        //写原值
        String timeStr = StringUtils.EMPTY;
        if (ldt != null) {
            // 获取到动态时区
            String utc = UserUtil.utc();
            LocalDateTime utcLdt = DateUtil.ldtUtc(ldt, utc);
            timeStr = DateUtil.formatDateTime(utcLdt, pattern);
        }
        gen.writeObject(timeStr);
    }

    @Override
    public JsonSerializer<?> createContextual(SerializerProvider serializerProvider, BeanProperty property) throws JsonMappingException {
        UtcOut utc = PojoUtil.annotationSerializable(property, false, UtcOut.class, LocalDateTime.class);
        if (utc != null) {
            this.pattern = TirsciUtil.utcPattern(utc.pattern(), () -> UserUtil.user().getOther());
            return this;
        }
        return null;
    }
}

==> applet-annotation-3.2.3-sources.jar: cn/sinozg/applet/common/serializer/UtcOutSerializer.java <==
/*
 * Copyright (C) 2020-2024, Xie YuBin
 * The GNU Free Documentation License covers this file. The original version
 * of this license can be found at http://www.gnu.org/licenses/gfdl.html.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Free Documentation License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Free Documentation License for more details.
 *
 * You should have received a copy of the GNU Free Documentation License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package cn.sinozg.applet.common.serializer;

import cn.sinozg.applet.common.annotation.UtcOut;
import cn.sinozg.applet.common.utils.DateUtil;
import cn.sinozg.applet.common.utils.PojoUtil;
import cn.sinozg.applet.common.utils.TirsciUtil;
import cn.sinozg.applet.common.utils.UserUtil;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.BeanProperty;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.JsonSerializer;
import com.fasterxml.jackson.databind.SerializerProvider;
import com.fasterxml.jackson.databind.ser.ContextualSerializer;
import org.apache.commons.lang3.StringUtils;

import java.io.IOException;
import java.time.LocalDateTime;

/**
 * 时间根据utc 转为 显示时间
 * @author xieyubin
 * @Description
 * @Copyright Copyright (c) 2024
 * @since 2024-11-24 17:51
 */
public class UtcOutSerializer extends JsonSerializer<LocalDateTime> implements ContextualSerializer {

    private String pattern;

    @Override
    public void serialize(LocalDateTime ldt, JsonGenerator gen, SerializerProvider serializerProvider) throws IOException {
        //写原值
        String timeStr = StringUtils.EMPTY;
        if (ldt != null) {
            // 获取到动态时区
            try {
                String utc = UserUtil.utc();
                LocalDateTime utcLdt = DateUtil.utcLdt(ldt, utc);
                timeStr = DateUtil.formatDateTime(utcLdt, pattern);
            } catch (Exception ignored){
            }
        }
        gen.writeObject(timeStr);
    }

    @Override
    public JsonSerializer<?> createContextual(SerializerProvider serializerProvider, BeanProperty property) throws JsonMappingException {
        UtcOut utc = PojoUtil.annotationSerializable(property, false, UtcOut.class, LocalDateTime.class);
        if (utc != null) {
            this.pattern = TirsciUtil.utcPattern(utc.pattern(), () -> UserUtil.user().getOther());
            return this;
        }
        return null;
    }
}
